Crate rosin_core

Crate rosin_core 

Re-exports

pub use accesskit;
pub use keyboard_types;
pub use kurbo;
pub use log;
pub use parking_lot;
pub use parley;
pub use unic_langid;
pub use vello;
pub use vello::peniko;
pub use vello::wgpu;

Modules

css
Types related to styling the UI tree.
data
Types for UI parameters and text.
events
Types related to event handling and dispatch.
layout
Layout Guide
localization
Localization primitives built on top of Project Fluent.
nodeid
A stable and unique node identifier.
pointer
Pointer input types used by the event system.
prelude
The public API
reactive
Provides values that allow Rosin to track data dependencies automatically.
text
Exposes functions to access global shared parley contexts.
tree
Exposes the builder used to construct a UI tree.
viewport
The main entry point to the rosin-core library.

Macros

id
The preferred method for creating a NodeId.
stylesheet
Loads a CSS Stylesheet from a path relative to the crate root.
ui_format
Constructs a UIString with a custom format string.