pub enum FileDialogResponse {
Opened(Vec<PathBuf>),
Saved(PathBuf),
Cancelled,
}Expand description
The result of a file dialog interaction.
Variants
Opened(Vec<PathBuf>)
The user confirmed an Open operation. Contains the list of selected files or folders.
Saved(PathBuf)
The user confirmed a Save operation. Contains the destination path.
Cancelled
The user closed the dialog without confirming.
Implementations
Sourceimpl FileDialogResponse
impl FileDialogResponse
Sourcepub fn path(&self) -> Option<&PathBuf>
pub fn path(&self) -> Option<&PathBuf>
Returns the first selected path regardless of whether the dialog was Open or Save.
Sourcepub fn paths(&self) -> Vec<PathBuf>
pub fn paths(&self) -> Vec<PathBuf>
Returns all selected paths. If this was a Save dialog, it returns a vec with a single path.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if the user cancelled the dialog.