CanvasCtx

Struct CanvasCtx 

pub struct CanvasCtx<'a> {
    pub did_layout: bool,
    pub is_active: bool,
    pub is_enabled: bool,
    pub is_focused: bool,
    pub perf_info: &'a PerfInfo,
    pub rect: &'a RoundedRect,
    pub scene: &'a mut Scene,
    pub style: &'a Style,
    pub translation_map: TranslationMap,
}
A context provided to the on_canvas callback of a node for rendering.

CanvasCtx provides access to the Vello Scene for issuing graphics commands in local space, as well as the node’s layout information, computed styles, and interaction state (active/focused).

Fields

did_layout: boolis_active: boolis_enabled: boolis_focused: boolperf_info: &'a PerfInforect: &'a RoundedRectscene: &'a mut Scenestyle: &'a Styletranslation_map: TranslationMap

Implementations

Source

impl<'a> CanvasCtx<'a>

pub fn padding_box(&self) -> Rect

Returns the rect just inside the borders of the node in local space. Doesn’t account for rounded corners.

pub fn max_content_width(&self) -> f32

Returns the maximum width content could be before overflowing node.

pub fn draw_text(&mut self, text: &str)

Draw text according to this node’s CSS styles.

pub fn draw_text_at_origin( &mut self, origin: Point, max_width: impl Into<Option<f32>>, text: &str, )

Draw text at the provided location according to this node’s CSS styles.

pub fn draw_text_layout(&mut self, origin: Point, layout: &Layout<[u8; 4]>)

Draws a text layout at the specified location.