pub struct LocalizedStringBuilder { /* private fields */ }Expand description
Used to construct a LocalizedString
Implementations
Sourceimpl LocalizedStringBuilder
impl LocalizedStringBuilder
Sourcepub fn new(key: &'static str) -> Self
pub fn new(key: &'static str) -> Self
Creates a new builder. key is used to look up translations in a TranslationFile.
Sourcepub fn placeholder(self, text: &'static str) -> Self
pub fn placeholder(self, text: &'static str) -> Self
Provides a placeholder string to display when resolving fails.
Sourcepub fn arg(self, key: &'static str, value: impl Into<LocalizedArg>) -> Self
pub fn arg(self, key: &'static str, value: impl Into<LocalizedArg>) -> Self
Adds a value to be used as a localization argument when resolving the string. This can be a static value or a reactive variable.
Sourcepub fn build(self) -> LocalizedString
pub fn build(self) -> LocalizedString
Builds the LocalizedString.