macro_rules! stylesheet {
($path:literal) => { ... };
}Expand description
Loads a CSS Stylesheet from a path relative to the crate root.
In release builds, uses include_str to embed the CSS text into the binary.
macro_rules! stylesheet {
($path:literal) => { ... };
}Loads a CSS Stylesheet from a path relative to the crate root.
In release builds, uses include_str to embed the CSS text into the binary.