pub struct NodeId(/* private fields */);Expand description
A unique identifier for a node.
In view callbacks, create NodeIds with the crate::id macro.
Implementations
Sourceimpl NodeId
impl NodeId
Sourcepub fn next() -> Self
pub fn next() -> Self
Create a new NodeId. For times when the id!() macro isn’t appropriate, such as when creating ids in a loop.
Not suitable for use in a view callback since it returns a unique id every time.
Sourcepub fn set_counter(value: u64)
pub fn set_counter(value: u64)
Resume NodeId generation from a specific value.
This is useful in the exceptionally rare cases when resuming id creation
from a particular value with the NodeId::next() function is required.
Panics: if value is zero, as NodeId values must be non-zero.
Sourcepub fn get_counter() -> u64
pub fn get_counter() -> u64
Returns the current value of the NodeId generator.
Useful for persisting the id counter to resume later with NodeId::set_counter().