PointerEvent

Struct PointerEvent 

pub struct PointerEvent {
    pub viewport_pos: Point,
    pub wheel_delta: Vec2,
    pub button: PointerButton,
    pub buttons: PointerButtons,
    pub mods: Modifiers,
    pub count: u8,
    pub did_focus_window: bool,
    pub pressure: f32,
    pub tangential_pressure: f32,
    pub tilt: Vec2,
    pub twist: f32,
    pub pointer_type: PointerType,
}
Information about a pointer event.

Fields

viewport_pos: Point

The position of the pointer event in the viewport.

wheel_delta: Vec2

The scroll amount.

button: PointerButton

The button responsible for a pointer event. This will always be PointerButton::None for an On::PointerMove event.

buttons: PointerButtons

Pointer buttons being held down during a move or after a click event. It will contain the button that caused an On::PointerDown event, but it will not contain the button that caused an On::PointerUp event.

mods: Modifiers

Keyboard modifier keys pressed at the time of the event.

count: u8

The number of clicks associated with this event. This will always be 0 for On::PointerUp and On::PointerMove events.

did_focus_window: bool

This is set to true if the pointer event caused the window to gain focus.

pressure: f32

The normalized pressure of the pointer input in the range 0 to 1, where 0 and 1 represent the minimum and maximum pressure the hardware is capable of detecting, respectively.

tangential_pressure: f32

The normalized tangential pressure of the pointer input in the range -1 to 1, where 0 is the neutral position of the control.

tilt: Vec2

The tilt of the pen in the X and Y axis, from -1 to 1.

twist: f32

The clockwise rotation of the pen stylus around its major axis in degrees, with a value in the range 0 to 359.

pointer_type: PointerType

Indicates the device type that caused the event.