Var

Struct Var 

pub struct Var<T: Send + Sync + 'static>(/* private fields */);
A reactive value that affects on-screen content.

Viewports track when a Var is read, automatically determining which parts of the UI it affects. When the variable is modified, the required updates will be applied to the screen.

This derefs to WeakVar a non-owning, Copy handle.

Anything visible and dynamic should be stored in a Var.

Deadlock note: like other synchronization primitives, accessing Vars across threads in an inconsistent order can cause lock inversion, potentially leading to deadlocks. Always acquire locks in a consistent order to prevent this.

Implementations

Source

impl<T: Send + Sync + 'static> Var<T>

pub fn new(value: T) -> Self

Creates a new Var in the global registry with the specified initial value.

pub fn read<'a>(&'a self) -> VarReadGuard<'a, T>

Returns a read guard to the value if the Var is alive, marking it as read from.

pub fn write<'a>(&'a self) -> VarWriteGuard<'a, T>

Returns a write guard to the value if the Var is alive.

The guard handles marking the Var as written to and read from when it is dropped.

pub fn get_version(&self) -> u64

Returns the current version of the variable.

pub fn get(&self) -> T
where T: Clone,

Returns a clone of the stored value if it is still alive, marking it as read from.

pub fn set(&self, new: T)
where T: PartialEq,

Sets the value of the variable, but only bumps the version if the value actually changed.

pub fn replace(&self, new: T) -> T

Replaces the value in the registry and returns the old value.

pub fn take(&self) -> T
where T: Default,

Takes the current value, leaving Default::default() in its place.

pub fn downgrade(&self) -> WeakVar<T>

Returns a WeakVar that references the same value without taking ownership.

This is useful for storing or passing a handle to the value without keeping it alive. The returned WeakVar can be cheaply copied and used to access or update the value as long as the original Var is still alive.

Methods from Deref<Target = WeakVar<T>>

pub fn is_alive(&self) -> bool

Checks if the associated Var has been dropped.

pub fn get_version(&self) -> Option<u64>

Returns the current version of the variable.

pub fn read<'a>(&'a self) -> Option<VarReadGuard<'a, T>>

Returns a read guard to the value if the Var is alive, marking it as read from.

Returns None if the Var has been destroyed.

pub fn write<'a>(&'a self) -> Option<VarWriteGuard<'a, T>>

Returns a write guard to the value if the Var is alive.

The guard handles marking the Var as written to and read from when it is dropped.

Returns None if the Var has been destroyed.

pub fn get(&self) -> Option<T>
where T: Clone,

Returns a clone of the stored value if it is still alive, marking it as read from. Returns None otherwise.

pub fn get_or(&self, default: T) -> T
where T: Clone,

Returns the value if the Var is alive, or default if it has been dropped.

This method evaluates default eagerly, even if the value is alive. Use WeakVar::get_or_else to evaluate the default lazily.

pub fn get_or_else(&self, default: impl FnOnce() -> T) -> T
where T: Clone,

Returns a clone of the value if alive, or computes a default from the given closure.

Unlike WeakVar::get_or, this only evaluates default if the Var is dead.

pub fn set(&self, new: T) -> Option<()>
where T: PartialEq,

Sets the value of the variable, but only bumps the version if the value actually changed.

Returns None if the Var has been destroyed, Some(()) otherwise.

pub fn replace(&self, new: T) -> Option<T>

Replaces the value in the registry and returns the old value.

pub fn take(&self) -> Option<T>
where T: Default,

Takes the current value, leaving Default::default() in its place.

pub fn mark_read(&self)

Marks a Var as if it had been read from.

This is a no-op if the Var has been destroyed.