WeakVar

Struct WeakVar 

pub struct WeakVar<T: Send + Sync + 'static> { /* private fields */ }
A handle to a Var that implements Copy.

Intended to be stored in callbacks.

Implementations

Source

impl<T: Send + Sync + 'static> WeakVar<T>

pub fn is_alive(&self) -> bool

Checks if the associated Var has been dropped.

pub fn get_version(&self) -> Option<u64>

Returns the current version of the variable.

pub fn read<'a>(&'a self) -> Option<VarReadGuard<'a, T>>

Returns a read guard to the value if the Var is alive, marking it as read from.

Returns None if the Var has been destroyed.

pub fn write<'a>(&'a self) -> Option<VarWriteGuard<'a, T>>

Returns a write guard to the value if the Var is alive.

The guard handles marking the Var as written to and read from when it is dropped.

Returns None if the Var has been destroyed.

pub fn get(&self) -> Option<T>
where T: Clone,

Returns a clone of the stored value if it is still alive, marking it as read from. Returns None otherwise.

pub fn get_or(&self, default: T) -> T
where T: Clone,

Returns the value if the Var is alive, or default if it has been dropped.

This method evaluates default eagerly, even if the value is alive. Use WeakVar::get_or_else to evaluate the default lazily.

pub fn get_or_else(&self, default: impl FnOnce() -> T) -> T
where T: Clone,

Returns a clone of the value if alive, or computes a default from the given closure.

Unlike WeakVar::get_or, this only evaluates default if the Var is dead.

pub fn set(&self, new: T) -> Option<()>
where T: PartialEq,

Sets the value of the variable, but only bumps the version if the value actually changed.

Returns None if the Var has been destroyed, Some(()) otherwise.

pub fn replace(&self, new: T) -> Option<T>

Replaces the value in the registry and returns the old value.

pub fn take(&self) -> Option<T>
where T: Default,

Takes the current value, leaving Default::default() in its place.

pub fn mark_read(&self)

Marks a Var as if it had been read from.

This is a no-op if the Var has been destroyed.