pub struct Style {Show 71 fields
pub background_color: Color,
pub background_image: Option<GradientStack>,
pub border_bottom_color: Color,
pub border_bottom_left_radius: Length,
pub border_bottom_right_radius: Length,
pub border_bottom_width: Length,
pub border_left_color: Color,
pub border_left_width: Length,
pub border_right_color: Color,
pub border_right_width: Length,
pub border_top_color: Color,
pub border_top_left_radius: Length,
pub border_top_right_radius: Length,
pub border_top_width: Length,
pub bottom: Unit,
pub box_shadow: Option<Arc<[BoxShadow]>>,
pub child_between: Unit,
pub child_bottom: Unit,
pub child_left: Unit,
pub child_right: Unit,
pub child_top: Unit,
pub color: Color,
pub display: Option<Direction>,
pub flex_basis: Length,
pub font_family: Option<Arc<str>>,
pub font_size: f32,
pub font_style: FontStyle,
pub font_weight: f32,
pub font_width: f32,
pub height: Unit,
pub left: Unit,
pub letter_spacing: Option<Unit>,
pub line_height: Unit,
pub max_bottom: Option<Length>,
pub max_child_between: Option<Length>,
pub max_child_bottom: Option<Length>,
pub max_child_left: Option<Length>,
pub max_child_right: Option<Length>,
pub max_child_top: Option<Length>,
pub max_height: Option<Length>,
pub max_left: Option<Length>,
pub max_right: Option<Length>,
pub max_top: Option<Length>,
pub max_width: Option<Length>,
pub min_bottom: Option<Length>,
pub min_child_between: Option<Length>,
pub min_child_bottom: Option<Length>,
pub min_child_left: Option<Length>,
pub min_child_right: Option<Length>,
pub min_child_top: Option<Length>,
pub min_height: Option<Length>,
pub min_left: Option<Length>,
pub min_right: Option<Length>,
pub min_top: Option<Length>,
pub min_width: Option<Length>,
pub opacity: f32,
pub outline_color: Color,
pub outline_offset: Length,
pub outline_width: Length,
pub position: Position,
pub right: Unit,
pub selection_background: Color,
pub selection_color: Option<Color>,
pub text_align: TextAlign,
pub text_shadow: Option<Arc<[TextShadow]>>,
pub top: Unit,
pub transform: Affine,
pub visibility: bool,
pub width: Unit,
pub word_spacing: Option<Unit>,
pub z_index: i32,
}Expand description
Computed style properties of a Node.
The Ui::on_style callback gives an application the opportunity to modify a node’s style after CSS rules have been applied and before rendering.
Fields
background_color: Colorbackground_image: Option<GradientStack>border_bottom_color: Colorborder_bottom_left_radius: Lengthborder_bottom_right_radius: Lengthborder_bottom_width: Lengthborder_left_color: Colorborder_left_width: Lengthborder_right_color: Colorborder_right_width: Lengthborder_top_color: Colorborder_top_left_radius: Lengthborder_top_right_radius: Lengthborder_top_width: Lengthbottom: Unitbox_shadow: Option<Arc<[BoxShadow]>>child_between: Unitchild_bottom: Unitchild_left: Unitchild_right: Unitchild_top: Unitcolor: Colordisplay: Option<Direction>flex_basis: Lengthfont_family: Option<Arc<str>>font_size: f32font_style: FontStylefont_weight: f32font_width: f32height: Unitleft: Unitletter_spacing: Option<Unit>line_height: Unitmax_bottom: Option<Length>max_child_between: Option<Length>max_child_bottom: Option<Length>max_child_left: Option<Length>max_child_right: Option<Length>max_child_top: Option<Length>max_height: Option<Length>max_left: Option<Length>max_right: Option<Length>max_top: Option<Length>max_width: Option<Length>min_bottom: Option<Length>min_child_between: Option<Length>min_child_bottom: Option<Length>min_child_left: Option<Length>min_child_right: Option<Length>min_child_top: Option<Length>min_height: Option<Length>min_left: Option<Length>min_right: Option<Length>min_top: Option<Length>min_width: Option<Length>opacity: f32outline_color: Coloroutline_offset: Lengthoutline_width: Lengthposition: Positionright: Unitselection_background: Colorselection_color: Option<Color>If selection_color is None, selected text will not have a different color.
text_align: TextAligntext_shadow: Option<Arc<[TextShadow]>>top: Unittransform: Affinevisibility: boolwidth: Unitword_spacing: Option<Unit>z_index: i32Implementations
Sourceimpl Style
impl Style
pub fn get_font_layout_style(&self) -> FontLayoutStyle