pub struct CanvasCtx<'a> {
pub did_layout: bool,
pub is_active: bool,
pub is_enabled: bool,
pub is_focused: bool,
pub perf_info: &'a PerfInfo,
pub rect: &'a RoundedRect,
pub scene: &'a mut Scene,
pub style: &'a Style,
pub translation_map: TranslationMap,
}Expand description
Fields
did_layout: boolis_active: boolis_enabled: boolis_focused: boolperf_info: &'a PerfInforect: &'a RoundedRectscene: &'a mut Scenestyle: &'a Styletranslation_map: TranslationMapImplementations
Sourceimpl<'a> CanvasCtx<'a>
impl<'a> CanvasCtx<'a>
Sourcepub fn padding_box(&self) -> Rect
pub fn padding_box(&self) -> Rect
Returns the rect just inside the borders of the node in local space. Doesn’t account for rounded corners.
Sourcepub fn max_content_width(&self) -> f32
pub fn max_content_width(&self) -> f32
Returns the maximum width content could be before overflowing node.