#[repr(u8)]pub enum PointerButton {
None = 0,
Primary = 1,
Secondary = 2,
Auxiliary = 3,
X1 = 4,
X2 = 5,
}Expand description
Identifies a specific button on a pointer device.
Variants
None = 0
Primary = 1
The primary pointer button, usually the left mouse button.
Secondary = 2
The secondary pointer button, usually the right mouse button.
Auxiliary = 3
The auxiliary pointer button, usually the wheel or middle mouse button.
X1 = 4
The fourth pointer button, usually the back button.
X2 = 5
The fifth pointer button, usually the forward button.
Implementations
Sourceimpl PointerButton
impl PointerButton
Sourcepub fn is_primary(self) -> bool
pub fn is_primary(self) -> bool
Returns true if this is PointerButton::Primary.
Sourcepub fn is_secondary(self) -> bool
pub fn is_secondary(self) -> bool
Returns true if this is PointerButton::Secondary.
Sourcepub fn is_auxiliary(self) -> bool
pub fn is_auxiliary(self) -> bool
Returns true if this is PointerButton::Auxiliary.
Sourcepub fn is_x1(self) -> bool
pub fn is_x1(self) -> bool
Returns true if this is PointerButton::X1.
Sourcepub fn is_x2(self) -> bool
pub fn is_x2(self) -> bool
Returns true if this is PointerButton::X2.